#!/bin/bash
#

# buildPython.sh <product_dir> [tar] [source]

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

get_platform_name()
{
    OS1=`uname`
    flvr=`ups flavor`
    if [ ${OS1} = "Darwin" ]
    then
	flvr=`ups flavor -2`
    fi
    OS=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform`
    plat=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform osplat`

    if [ -z ${flvr} ]
    then
       echo "ERROR: could not determine flavor for this platform"
       echo "       something is very wrong"
       exit 1
    fi

    pkgdir=${product_dir}/${package}/${pkgver}/${flvr}
    sourcedir=${product_dir}/${package}/${pkgver}/source
    blddir=${product_dir}/${package}/${pkgver}/build/${flvr}
    tardir=${product_dir}/${package}/${pkgver}/tar
    sourcedir=${product_dir}/${package}/${pkgver}/source
}

declare_product()
{
    echo "Declaring ${package} ${pkgver} for ${flvr}"
    if [ ${OS1} = "Darwin" ]
    then
       ups declare ${package} ${pkgver} -r ${package}/${pkgver} -2 -m ${package}.table  -z ${product_dir}
    else 
       ups declare ${package} ${pkgver} -r ${package}/${pkgver} -4 -m ${package}.table  -z ${product_dir}
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}
sourcetar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=python
pkgver=v2_7_5
ssibuildshims_version=v0_06_01
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=Python-${pkgdotver}

get_this_dir

get_ssibuildshims

if [ "${sourcetar}" = "source" ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_source_code_tarball ${product_dir} ${package} ${pkgver}
fi

get_platform_name

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
    exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`

set -x

cd ${sourcedir}
tar xf ${tardir}/${pkgtarname}.tar.bz2

cd ${blddir}
${sourcedir}/${pkgtarname}/configure --prefix=${pkgdir} --enable-shared
make -j ${ncore}
make install

set +x

# replace idle, pydoc, and smtpd.py with the scripts which use #!/usr/bin/env python
if [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi
cd ${pkgdir}/bin
cp -p ${sourcedir}/${pkgtarname}/Tools/scripts/2to3 .
cp -p ${sourcedir}/${pkgtarname}/Tools/scripts/pydoc .
cp -p ${sourcedir}/${pkgtarname}/Tools/scripts/idle .
cp -p ${sourcedir}/${pkgtarname}/Lib/smtpd.py .
mv python2.7-config python2.7-config.bak
cat python2.7-config.bak | sed 's%^#!.*python2.7$%#!/usr/bin/env python%' > python2.7-config
chmod +x python2.7-config

declare_product

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver}  -z ${product_dir}
echo "${package} is installed at ${PYTHONHOME}"
echo ""

# fix paths in ${PYTHONHOME}/lib/python2.7/config/Makefile

rm -f /tmp/python-fix.sh

echo "#!/bin/bash" > /tmp/python-fix.sh
echo "" >>  /tmp/python-fix.sh
echo "mv ${PYTHONHOME}/lib/python2.7/config/Makefile ${PYTHONHOME}/lib/python2.7/config/Makefile.bak" >> /tmp/python-fix.sh
echo "cat ${PYTHONHOME}/lib/python2.7/config/Makefile.bak | sed 's%${PYTHONHOME}%\$(PYTHONHOME)%' | sed 's%${PYTHON_DIR}/source%\$(PYTHON_DIR)/source%' | sed 's%LD_LIBRARY_PATH=${PYTHON_DIR}/build/${flvr}%LD_LIBRARY_PATH=\$(PYTHONHOME)/lib%' > ${PYTHONHOME}/lib/python2.7/config/Makefile" >> /tmp/python-fix.sh
echo "" >>  /tmp/python-fix.sh

chmod +x /tmp/python-fix.sh
/tmp/python-fix.sh


# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver}  NO_QUAL
fi

exit 0
